summaryrefslogtreecommitdiff
path: root/sys/dev/usb
diff options
context:
space:
mode:
Diffstat (limited to 'sys/dev/usb')
-rw-r--r--sys/dev/usb/ueagle.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/sys/dev/usb/ueagle.c b/sys/dev/usb/ueagle.c
index 64f7b5afa7c..2f90850a459 100644
--- a/sys/dev/usb/ueagle.c
+++ b/sys/dev/usb/ueagle.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: ueagle.c,v 1.25 2010/04/21 21:07:47 claudio Exp $ */
+/* $OpenBSD: ueagle.c,v 1.26 2010/06/05 13:06:57 damien Exp $ */
/*-
* Copyright (c) 2003-2006
@@ -610,10 +610,10 @@ ueagle_boot(struct ueagle_softc *sc)
sc->ovl = 0;
ueagle_loadpage(sc);
/* wait until modem reaches operationnal state */
error = tsleep(UEAGLE_COND_READY(sc), PZERO | PCATCH, "boot", 10 * hz);
if (error != 0) {
- printf("%s: timeout waiting for operationnal state\n",
+ printf("%s: timeout waiting for operational state\n",
sc->sc_dev.dv_xname);
return error;
}
@@ -610,10 +610,10 @@ ueagle_boot(struct ueagle_softc *sc)
sc->ovl = 0;
ueagle_loadpage(sc);
- /* wait until modem reaches operationnal state */
+ /* wait until modem reaches operational state */
error = tsleep(UEAGLE_COND_READY(sc), PZERO | PCATCH, "boot", 10 * hz);
if (error != 0) {